@@ -58,9 +58,6 @@
 #include <QTreeWidget>
 #include <QVariant>
 #include <QVBoxLayout>
-#if QT_VERSION >= 0x50000
-# include <QUrlQuery>
-#endif
 
 #include <libdjvu/ddjvuapi.h>
 #include <libdjvu/miniexp.h>
@@ -171,7 +168,6 @@ QDjViewOutline::refresh()
               QString name = djview->pageName(pageno);
               item->setText(0, tr("Page %1").arg(name));
               item->setData(0, Qt::UserRole, pageno);
-              item->setData(0, Qt::UserRole+1, pageno);
               item->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEnabled);
               item->setToolTip(0, tr("Go: page %1.").arg(name));
               item->setWhatsThis(0, whatsThis());
@@ -190,22 +186,15 @@ QDjViewOutline::pageNumber(const char *link)
     return djview->pageNumber(QString::fromUtf8(link+1));
   if (link == 0 || link[0] != '?')
     return -1;
-  QByteArray burl = QByteArray("http://f/f") + link;
-#if QT_VERSION >= 0x50000
-  QUrlQuery qurl(QUrl::fromEncoded(burl));
-#else
-  QUrl qurl = QUrl::fromEncoded(burl);
-#endif
-  if (qurl.hasQueryItem("page"))
-    return djview->pageNumber(qurl.queryItemValue("page"));
-  else if (qurl.hasQueryItem("pageno"))
-    return djview->pageNumber("$" + qurl.queryItemValue("pageno"));
+  QUrl url = QUrl::fromEncoded(QByteArray("http://f/f") + link);
+  if (url.hasQueryItem("page"))
+    return djview->pageNumber(url.queryItemValue("page"));
+  else if (url.hasQueryItem("pageno"))
+    return djview->pageNumber("$" + url.queryItemValue("pageno"));
   return -1;
 }
 
 
-static const QRegExp spaces("\\s+");
-
 void 
 QDjViewOutline::fillItems(QTreeWidgetItem *root, miniexp_t expr)
 {
@@ -224,9 +213,8 @@ QDjViewOutline::fillItems(QTreeWidgetItem *root, miniexp_t expr)
           int pageno = pageNumber(link);
           QString pagename = (pageno>=0)?djview->pageName(pageno):QString();
           QTreeWidgetItem *item = new QTreeWidgetItem(root);
-          QString text = QString::fromUtf8(name);
           if (name && name[0])
-            item->setText(0, text.replace(spaces," "));
+            item->setText(0, QString::fromUtf8(name));
           else if (! pagename.isEmpty())
             item->setText(0, tr("Page %1").arg(pagename));
           item->setFlags(0);
@@ -306,12 +294,6 @@ QDjViewOutline::itemActivated(QTreeWidgetItem *item)
       if (link.size() > 0)
         djview->goToLink(link);
     }
-  else if (data.type() == QVariant::Int)
-    {
-      int pageno = data.toInt();
-      if (pageno >= 0)
-        djview->goToPage(pageno);
-    }
 }
 
 
@@ -336,6 +318,7 @@ protected:
   QStyleOptionViewItem viewOptions() const;
 private:
   QDjViewThumbnails *widget;
+  QDjView *djview;
 };
 
 
@@ -380,7 +363,8 @@ private:
 
 QDjViewThumbnails::View::View(QDjViewThumbnails *widget)
   : QListView(widget), 
-    widget(widget)
+    widget(widget), 
+    djview(widget->djview)
 {
   setDragEnabled(false);
   setEditTriggers(QAbstractItemView::NoEditTriggers);
@@ -735,7 +719,7 @@ QDjViewThumbnails::QDjViewThumbnails(QDjView *djview)
   action->setData(true);
   updateActions();
 
-#ifdef Q_OS_DARWIN
+#ifdef Q_WS_MAC
   QString mc = tr("Control Left Mouse Button");
 #else
   QString mc = tr("Right Mouse Button");
@@ -1148,21 +1132,6 @@ parse_text_type(miniexp_t exp)
   return -1;
 }
 
-static int count_final_spaces(const QString &s)
-{
-  int c = 0;
-  int l = s.size();
-  while (l>0 && s[--l].isSpace())
-    c += 1;
-  return c;
-}
-
-static QString chopped(QString s, int c)
-{
-  s.chop(c);
-  return s;
-}
-
 static bool
 miniexp_get_text(miniexp_t exp, QString &result, 
                  QMap<int,miniexp_t> &positions, int &state)
@@ -1179,14 +1148,10 @@ miniexp_get_text(miniexp_t exp, QString &result,
   state = qMax(state, typenum);
   if (miniexp_stringp(s) && !miniexp_cdr(r))
     {
-      int c = count_final_spaces(result);
-      if (state >= 2 && !result.endsWith('\n'))
-        result = chopped(result,c) + "\n";
-      else if (state >= 1 && c == 0)
-        result += " ";
+      result += (state >= 2) ? "\n" : (state >= 1) ? " " : "";
       state = -1;
       positions[result.size()] = exp;
-      result += QString::fromUtf8(miniexp_to_str(s)).trimmed();
+      result += QString::fromUtf8(miniexp_to_str(s));
       r = miniexp_cdr(r);
     }
   while(miniexp_consp(s))
@@ -1433,7 +1398,7 @@ QDjViewFind::Model::animTimeout()
 {
   if (animButton && !animIcon.isNull())
     {
-      if (animButton->icon().cacheKey() == findIcon.cacheKey())
+      if (animButton->icon().serialNumber() == findIcon.serialNumber())
         animButton->setIcon(animIcon);
       else
         animButton->setIcon(findIcon);
